@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class ImportImapSettingNoFoundPageTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit ImportImapSettingNoFoundPageTest(QObject *parent = Q_NULLPTR);
+    explicit ImportImapSettingNoFoundPageTest(QObject *parent = nullptr);
     ~ImportImapSettingNoFoundPageTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
